"""Core components."""

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

from .core import (
    StringEnum,
    # string_enum,
)
try:
    del core
except NameError:
    pass



"""Core components of the ezenum package."""

import collections.abc
import enum



class StringEnum(collections.abc.Sequence):
    """Easy, ordered enum-like objects from String lists.

    Arguments
    ---------
    members : list
        A list of strings,

    Example
    -------
    >>> colors = StringEnum(['Red', 'Blue', 'Green'])
    >>> colors.Red
    'Red'
    """
    def __init__(self, members):
        self.members = members
        for name in members:
            setattr(self, name, name)
    def __getitem__(self, index):
        return self.members[index]
    def __len__(self):
        return len(self.members)
    def __repr__(self):
        return str(self.members)


# class StringEnum(enum.Enum):


# def string_enum(name, member_list):
#     """Get an orderable enum of strings from the given list."""
#     return type(name, (enum.EnumMeta), {
#         member: member for member in member_list
#     })



"""Setup for the ezenum package."""

#!/usr/bin/env python
# -*- coding: utf-8 -*-

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import versioneer


README_RST = ''
with open('README.rst') as f:
    README_RST = f.read()

TEST_REQUIRES = ['pytest', 'coverage', 'pytest-cov']


setup(
    name='grodus',
    description="Great package.",
    long_description=README_RST,
    author="Shay Palachy",
    author_email="shaypal5@gmail.com",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    url='https://github.com/shaypal5/ezenum',
    license="MIT",
    packages=['grodus'],
    install_requires=[],
    extras_require={
        'test': TEST_REQUIRES
    },
    setup_requires=TEST_REQUIRES,
    platforms=['any'],
    keywords='enum',
    classifiers=[
        # Trove classifiers
        # (https://pypi.python.org/pypi?%3Aaction=list_classifiers)
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
    ],
)
